#
# spec file for package icedtea-web
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# this is the right version openjdk for us!
%define openjdk_ver 1.6.0.0_b22.1.10.1

# for openSUSE 11.1 we need use update repo as it were not
# released with this version
%define xulrunner_ver 191
%if 0%{?suse_version} > 1130
%define xulrunner_ver 20
%endif
%if 0%{?suse_version} == 1130
%define xulrunner_ver 192
%endif

%define with_npapisdk 0
%if 0%{?suse_version} > 1140
%define with_npapisdk 1
%endif

%ifarch %{ix86}
%define archinstall i386
%endif
%ifarch x86_64
%define archinstall amd64
%endif
%define priority        17106

%define javaver         1.6.0

# use a same name of alternatives as Sun/IBM Java
%define javaplugin      javaplugin

%define pluginsdir      %{_libdir}/browser-plugins
%define sdkdir          java-%{javaver}-openjdk-%{javaver}
%define pluginpath      %{_libdir}
%define pluginname      IcedTeaPlugin.so

Name:           icedtea-web
Version:        1.1.4
Release:        0.2.1
Summary:        Java Web Start and plugin implementation
Group:          Development/Languages/Java
License:        GPL-2.0-with-classpath-exception
Url:            http://icedtea.classpath.org
Source0:        http://icedtea.classpath.org/download/source/%{name}-%{version}.tar.gz
Patch0:         icedtea-web-1.0.2-no-return-in-nonvoid-function.patch
#PATCH-FIX-UPSTREAM:
# https://bugzilla.mozilla.org/show_bug.cgi?id=582130
# http://icedtea.classpath.org/bugzilla/show_bug.cgi?id=622
Patch1:         icedtea-web-1.1-moonlight-symbol-clash.patch
Patch2:         icedtea-web-npapi-sdk-r5.patch
Patch1000:      icedtea-web-suse-desktop-files.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  java-1_6_0-openjdk-devel
BuildRequires:  pkgconfig >= 0.9.0

# IcedTeaPlugin build requirements.
BuildRequires:  glib2-devel
BuildRequires:  gtk2-devel
%if %{with_npapisdk}
BuildRequires:  pkgconfig(npapi-sdk)
#FIXME: use after deprecation of mozilla-xulrunner* packages from Factory
#BuildRequires:  pkgconfig(libxul)
BuildRequires:  xulrunner-devel
%else
BuildRequires:  mozilla-nspr-devel
BuildRequires:  mozilla-xulrunner%{xulrunner_ver}-devel
%endif
%if %defined suse_version
BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  gcc-c++
BuildRequires:  update-desktop-files
BuildRequires:  zip
%endif

# to make sure the new package is installed in time of post
Requires(post):   java-1_6_0-openjdk >= %{openjdk_ver}
# Post requires alternatives to install tool alternatives.
Requires(post):   update-alternatives
# Postun requires alternatives to uninstall tool alternatives.
Requires(postun): update-alternatives

# there were nothing like 1.9.8 in openSUSE
Provides:       java-1_6_0-openjdk-plugin = %{openjdk_ver}
Obsoletes:      java-1_6_0-openjdk-plugin < %{openjdk_ver}
Provides:       java-1.6.0-openjdk-plugin = %{openjdk_ver}
Provides:       java-plugin = %{javaver}

%description
The IcedTea-Web project provides a Free Software web browser plugin running
applets written in the Java programming language and an implementation of Java
Web Start, originally based on the NetX project.
%package javadoc


Summary:        API documentation for %{name}
Group:          Documentation/Other
%if 0%{?suse_version} >= 1120
BuildArch:      noarch
%endif

%description javadoc
This package contains Javadocs for the %{name}.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%if %{with_npapisdk}
%patch2 -p1
%endif

%patch1000 -p1

%build
%{configure} \
    --with-jdk-home=%{_jvmdir}/%{sdkdir} \
    --with-jre-home=%{_jvmdir}/jre/ \
    --docdir=%{_javadocdir}/%{name} \
    --with-pkgversion=suse-%{release}-%{_arch} 

make

%install
%{makeinstall}

# the --program-suffix rename both binaries, so let's handle it here
mv %{buildroot}/%{_bindir}/javaws %{buildroot}/%{_bindir}/itweb-javaws
# and manual page is still used in u-a, so let's move it
mv %{buildroot}/%{_mandir}/man1/javaws.1 %{buildroot}/%{_datadir}/%{name}/
rm -rf %{buildroot}/%{_mandir}

# Install desktop files.
install -d -m 755 %{buildroot}%{_datadir}/{applications,pixmaps}
cp javaws.png %{buildroot}%{_datadir}/pixmaps
for d in javaws itweb-settings; do
   install -m 0644 $d.desktop %{buildroot}/%{_datadir}/applications/
    %suse_update_desktop_file $d
done

# needs for sle-11-sp1 and openSUSE evergreen
export NO_BRP_CHECK_BYTECODE_VERSION=true

%clean
rm -rf %{buildroot}

%posttrans
# java-1_6_0-openjdk-plugin -> icedtea-web is remove of the first package
# which causes a javaplugin removal, so let's move it here
/usr/sbin/update-alternatives \
  --install %{pluginsdir}/javaplugin.so %{javaplugin} \
  %{pluginpath}/%{pluginname} %{priority} \
  --slave %{_bindir}/javaws javaws %{_bindir}/itweb-javaws \
  --slave %{_mandir}/man1/javaws.1 javaws.1 \
  %{_datadir}/%{name}/javaws.1

%postun
if [ $1 -eq 0 ]
then
update-alternatives --remove %{javaplugin} \
    %{pluginpath}/%{pluginname}
fi

%files
%defattr(-,root,root,-)
%doc NEWS README COPYING
%{_bindir}/itweb-settings
%{_bindir}/itweb-javaws
%{pluginpath}/%{pluginname}
%{_datadir}/%{name}
%{_datadir}/applications/itweb-settings.desktop
%{_datadir}/applications/javaws.desktop
%{_datadir}/pixmaps/javaws.png

%files javadoc
%defattr(-,root,root,-)
%{_javadocdir}/%{name}

%changelog
* Mon Nov 14 2011 mvyskocil@suse.cz
- update to 1.1.4 (fixes bnc#729870)
  - RH742515, CVE-2011-3377: IcedTea-Web: second-level domain subdomains and
    suffix domain SOP bypass
  - PR778: Jar download and server certificate verification deadlock
* Mon Oct 24 2011 mvyskocil@suse.cz
- update to 1.1.3:
  - PR782: Support building against npapi-sdk as well
  * drop the added patch
  - PR794: IcedTea-Web does not work if a Web Start app jar has a
    Class-Path element in the manifest
- icedtea-web-npapi-sdk-r5.patch for build with npapi-sdk we have
  in openSUSE
* Mon Oct 10 2011 gber@opensuse.org
- fix icedtea-web-suse-desktop-files.patch, itweb-settings is a
  desktop setting and should not show up twice in two unrelated
  top-level menus; also add a trailing semicolon
* Thu Sep 15 2011 mvyskocil@suse.cz
- Build with a npapi-sdk and xulrunner-devel from openSUSE 12.1
* Tue Sep  6 2011 cfarrell@suse.com
- license update: GPL-2.0-with-classpath-exception
  SPDX syntax. See http://spdx.org/licenses
* Fri Sep  2 2011 mvyskocil@suse.cz
- update to 1.1.2
  * PR749: sun.applet.PluginStreamHandler#handleMessage(String) really slow
  * RH718693: MindTerm SSH Applet doesn’t work
  * PR768: Signed applets/Web Start apps don’t work with OpenJDK7 and up
  * PR769: IcedTea-Web does not work with some ssl sites with OpenJDK7
  * RH734081: Javaws cannot use proxy settings from Firefox
  * New (--with-jre-home=) option to allow use with only JRE installed
- use a common jre location libdir/jvm/jre instead of openjdk6
- obsoleted CVE patches
* Wed Jul 20 2011 mvyskocil@suse.cz
- fix bnc#704309 - VUL-0: icedtea/icedtea-web two issues
  * CVE-2011-2513
  * CVE-2011-2514
- use --with-java instead of patching of launchers as
  suggested by upstream
* Fri Jul  8 2011 mvyskocil@suse.cz
- fix bnc#704419 - Use correct path in IcedteaPlugin.so
  * allow plugin usage without -devel package installed
  * fix lanchers location from JAVA to JRE
  * icedtea-1.1-use-jre-in-launchers.patch
* Thu Jun 30 2011 mvyskocil@suse.cz
- fic bnx#702825 - IcedTeaPlugin.so gives undefined symbol
  * fix the icedtea-web-1.1-moonlight-symbol-clash.patch
* Fri Jun 10 2011 mvyskocil@suse.cz
- Update to 1.1 - triggered by icedtea-1.10.2 security update (bnc#698739)
- New features:
  * IcedTea-Web now installs to a FHS-compliant location
  * Binary launchers have been replaced with simple shell scripts
  * Proxy Auto Config files are now usable
  * Applications using jnlp.versionEnabled and jnlp.packEnabled are now supported
  * Can now use codebase_lookup=false with applets
  * itweb-settings now supports clearing cache
- Common fixes
  * Apps calling loadClass get a proper a ClassNotFoundException if class is
    not found, rather than a null value
  * Applets and JNLP apps using SSL/TLS now function correctly
-  Web Start implementation (javaws) fixes:
  * The Web Start implementation can now use proxy settings from Firefox
  * Web Start applications now use the correct default browser set by the user
  * Closing javaws -about no longer throws exceptions
  * Cache files are removed properly
- Plug-in fixes:
  * Applets from the same page to use the same classloader (MS LiveMeeting,
    www.uk.map24.com, etc.)
  * NetDania banking application now works (bnc#608132)
  * Sound now works with runescape.com (bnc#542457)
  * Firefox 4 no longer freezes if the applet calls showDocument()
  * Firefox 4 and chromium stability has been vastly improved with a rewrite of
    the plug-in threading model
* Tue Apr 12 2011 mvyskocil@suse.cz
- Initial SUSE packaging of 1.0.2
  * just follow upstream's split of web tools to icedtea-web
